@@ -11,10 +11,10 @@ pub fn main() {
 
     let starting_state = MainState::new();
 
-    let (context, event_loop) = ContextBuilder::new().build();
+    let context = ContextBuilder::new().build();
     WolfEngineBuilder::with_default_game_loop()
         .build(context)
-        .run(Box::from(starting_state), event_loop);
+        .run(Box::from(starting_state));
 }
 
 pub struct MainState {
