@@ -11,10 +11,10 @@ pub fn main() {
 
     let my_state = MyState::new("Hello, World!");
 
-    let (context, event_loop) = ContextBuilder::new().build();
+    let context = ContextBuilder::new().build();
     WolfEngineBuilder::with_default_game_loop()
         .build(context)
-        .run(Box::from(my_state), event_loop);
+        .run(Box::from(my_state));
 }
 
 pub struct MyState {
